@@ -143,7 +143,7 @@ __END__
 
 =head1 NAME
 
-Finance::NASDAQ::Markets - Perl extension for blah blah blah
+Finance::NASDAQ::Markets - Perl extension to download realtime quotes for all major markets indices sectors
 
 =head1 SYNOPSIS
 
@@ -155,28 +155,18 @@ Finance::NASDAQ::Markets - Perl extension for blah blah blah
 
 =head1 DESCRIPTION
 
-Stub documentation for Finance::NASDAQ::Markets, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Loads Sectors and Index quotes and changes
+Loads the quotes and change pct. information 
+for a wide range of indices and sectors
+from nasdaq. should be realtime!
 
 =head2 EXPORT
 
 None by default.
 
-
-
 =head1 SEE ALSO
 
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
+Finance::Optical::StrongBuy
+Finance::Google::Sector::Mean
 
 =head1 AUTHOR
 
@@ -184,7 +174,7 @@ Hagen Geissler
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012 by sante zero
+Copyright (C) 2012 by Hagen Geissler
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.12.4 or,
